+{
   locale_version => 1.26,
   entry => <<'ENTRY', # for DUCET v9.0.0
0451      ; [.205B.0020.0002] # CYRILLIC SMALL LETTER IO
0435 0308 ; [.205B.0020.0002] # CYRILLIC SMALL LETTER IO
0401      ; [.205B.0020.0008] # CYRILLIC CAPITAL LETTER IO
0415 0308 ; [.205B.0020.0008] # CYRILLIC CAPITAL LETTER IO
04AF      ; [.2126.0020.0002] # CYRILLIC SMALL LETTER STRAIGHT U
04AE      ; [.2126.0020.0008] # CYRILLIC CAPITAL LETTER STRAIGHT U
0456      ; [.2197.0020.0002] # CYRILLIC SMALL LETTER BYELORUSSIAN-UKRAINIAN I
0406      ; [.2197.0020.0008] # CYRILLIC CAPITAL LETTER BYELORUSSIAN-UKRAINIAN I
0457      ; [.2197.0020.0002][.0000.002B.0002] # CYRILLIC SMALL LETTER YI
A676      ; [.2197.0020.0004][.0000.002B.0004] # COMBINING CYRILLIC LETTER YI
0407      ; [.2197.0020.0008][.0000.002B.0002] # CYRILLIC CAPITAL LETTER YI
ENTRY
};
